import { BufferGeometry, Geometry, Vector3 } from "three";
import { LineGeometry } from "three/examples/jsm/lines/LineGeometry";
import { Curve } from "../DatabaseServices/Entity/Curve";
import { Polyline } from "../DatabaseServices/Entity/Polyline";
/**
 * 使用轮廓和扫描路径构建扫描几何体,实现衣柜中的顶线或者地脚线之类的实体.
 * 该几何体需要轮廓和路径的起始截面垂直,否则构造的实体将会错误.
 */
export declare class SweepGeometry extends Geometry {
    edgePts: number[];
    ShapeMaterialSlotData: number[];
    constructor(contour: Polyline, path: Curve[] | Curve, ShapeMaterialSlotData?: number[]);
    get LineGeom(): LineGeometry;
    get EdgeGeom(): BufferGeometry;
    AddShape(contour: Polyline, path: Curve): void;
    AddShape2(contour: Polyline, paths: Curve[]): void;
    private BuildSideFaces;
    private BuildLid;
}
/**
 * 将轮廓变换到`路径上某个点`.
 *
 * @param {Vector3[]} contourPts 原始的轮廓点(在世界坐标系)
 * @param {Vector3} normal 路径法向量
 * @param {Vector3} curP 路径上当前点
 * @param {Vector3} [preP] 路径的前一个点
 * @param {Vector3} [nextP] 路径下一个点
 * @returns 变换后的轮廓点表
 */
export declare function ProjectionToPlane(contourPts: Vector3[], normal: Vector3, curP: Vector3, preP?: Vector3, nextP?: Vector3): Vector3[];
//# sourceMappingURL=SweepGeometry.d.ts.map